HaptikSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HaptikSdkPlatform

Constructors

HaptikSdkPlatform()
Constructs a HaptikSdkPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

methodChannel MethodChannel
final

Static Methods

destroy() Future<String?>
getFormattedNotificationText(dynamic data) Future<String?>
handleNotification(dynamic data) Future<String?>
isHaptikNotification(dynamic data) Future<bool?>
launchCustomSignupConversation(SignupData signupData) Future<String?>
launchGuestConversation(InitData initData) Future<String?>
logout() Future<String?>
setLaunchMessage(String message, bool hidden, bool skipMessage) Future<String?>
setNotificationToken(String data) Future<String?>
updateUserData(dynamic userData) Future<String?>